            
*          
*           JULIAN DATE CONVERSION FUNCTIONS FOR CLIPPER  
*                                                         
*          ۱
*          
***********************************************************************
**                        FUNCTION CTOJ()                            **
***********************************************************************
* Character TO Julian
* Purpose.....:  Converts string to Julian Date
* Conventions.:  Julian Date is of the form YYDDD
*             : 
* Syntax......:  CTOJ(string)
*             : 
* Parameters..:  string   - a date string in the form '99/99/99'
*             : 
* Example.....:  CTOJ('07/19/89')  - returns the integer 89200
* Assumes.....:  valid date is passed in the form '99/99/99'
* Side Effects:  it won't crash with an invalid date; it'll just be wrong
* Returns.....:  an integer date value: '07/19/89' = 89200
* Calls.......: 
***********************************************************************

FUNCTION CTOJ
PARAMETER string

PRIVATE m_month, m_day, m_year, last_year, begin_str, end_str, begin_date, end_date, total_days,k_yrs
string = SUBSTR(ALLTRIM(string),1,8)
m_month = SUBSTR(string,1,2)
m_day = SUBSTR(string,4,2)
m_year = SUBSTR(string,7,2)
last_year = STR(INT(VAL(m_year)-1))
IF m_month > '12' .OR. m_month < '01' .OR. m_day > '31' .OR. m_day < '01'
  RETURN 0
ELSE
  begin_str = '12/31/' + last_year
  end_str = m_month + '/' + m_day + '/' + m_year
  begin_date = CTOD(begin_str)
  end_date   = CTOD(end_str)
  total_days = end_date - begin_date
  k_yrs = VAL(m_year) * 1000
  julian = k_yrs + total_days
  RETURN julian
ENDIF
** end of CTOJ()

***********************************************************************
**                        FUNCTION JTOD()                            **
***********************************************************************
* Julian TO Date
* Purpose.....: Julian to Standard Date conversion
* Conventions.: Converts to Standard dates in the form MM/DD/YY
*             : 
* Syntax......: JTOD(date) 
*             : 
* Parameters..: date -  a numeric variable in the format  YYDDD
*             :         
* Examples....: JTOD(m_date) ; JTOD(89200)
* Assumes.....: variable is a valid Julian date in the format specified
* Side Effects: 
* Returns.....: Standard MM/DD/YY date variable. (e.g., 7/20/89)
* Calls.......: 
***********************************************************************

FUNCTION JTOD
PARAMETER julian

PRIVATE jul_str, m_year, last_year, total_days, begin_str, begin_date
* convert numeric Julian date to standard date
jul_str = ALLTRIM(STR(INT(julian)))
m_year = SUBSTR(jul_str,1,2)
last_year = STR(INT(VAL(m_year)-1))
total_days = INT(VAL(SUBSTR(jul_str,3,3)))

IF total_days > 366 .OR. total_days < 1 
  RETURN 0
ELSE
  begin_str = '12/31/' + last_year
  begin_date = CTOD(begin_str)
  m_date   = begin_date + total_days
  RETURN m_date
ENDIF
** end of JTOD()

** <end of file>
